---
title: 'contentfilter:scanner'
url: 'https://docs.danami.com/warden/command-line-interface/contentfilter/contentfilter-scanner'
markdown: 'https://docs.danami.com/warden/command-line-interface/contentfilter/contentfilter-scanner.md'
date: '2026-10-07'
description: 'Configure the content filter scanner backend settings. warden --task=contentfilter:scanner Option Value Default Description --av_scanners <string1,string2> [''ClamAV-clamd'', \&ask_daemon, ["CONTSCAN {}\n", "/run/clamd.scan/clamd.sock"], qr/\bOK$/m, qr/\bFOUND$/m, qr/^.?: (?!Infected Ar…'
taxonomy:
  category:
    - docs
  tag:
    - amavis
---

[](#)  [ Basics ](https://docs.danami.com/warden/)     [ Command Line Interface ](https://docs.danami.com/warden/command-line-interface)      Contentfilter       contentfilter:scanner    

# contentfilter:scanner

Configure the content filter scanner backend settings.

```
warden --task=contentfilter:scanner
```

| Option | Value | Default | Description |
|---|---|---|---|
| `--av_scanners` | <string1,string2> | \['ClamAV-clamd', \\&ask\_daemon, \["CONTSCAN {}\\n", "/run/clamd.scan/clamd.sock"\], qr/\\bOK$/m, qr/\\bFOUND$/m, qr/^.*?: (?!Infected Archive)(.*) FOUND$/m \] | The list of primary antivirus scanners. Single quotes must be properly escaped replacing a single quote with '\\'' |
| `--av_scanners_add` | <string> |  | Add a single entry to av\_scanners. |
| `--av_scanners_del` | <string> |  | Remove a single entry from av\_scanners. |
| `--av_scanners_backup` | <string1,string2> | \['ClamAV-clamscan', 'clamscan', "--stdout --no-summary -r --tempdir=$TEMPBASE {}", \[0\], qr/:.*\\sFOUND$/m, qr/^.*?: (?!Infected Archive)(.\*) FOUND$/m \] | The list of backup antivirus scanners to use if the primary scanners fail. Single quotes must be properly escaped replacing a single quote with '\\'' Note: ClamAV-clamscan is not suitable as a backup scanner on busy servers because the ClamAV signatures have to be loaded into memory for every scan therefor we recommend that admins set the anti-virus scanners backup to none to disable the backup scanner if you are sending large amounts of mail. |
| `--av_scanners_backup_add` | <string> |  | Add a single entry to av\_scanners\_backup. |
| `--av_scanners_backup_del` | <string> |  | Remove a single entry from av\_scanners\_backup. |
| `--banned_rules` | <string1,string2> | 'DEFAULT' => $banned\_filename\_re | The list of banned rules (comma separated). Single quotes must be properly escaped replacing a single quote with '\\'' Added rules will be accessible under the server, domain, and mailbox level policies. The `'DEFAULT' => $banned_filename_re` rule points to the global amavisd.conf banned rules and should be included at all times. |
| `--banned_rules_add` | <string> |  | Add a single entry to banned\_rules. |
| `--banned_rules_del` | <string> |  | Remove a single entry from banned\_rules. |
| `--default` | <yes> |  | Reset all settings to their default values. |
| `--default_option` | <option> |  | Reset a specific setting to its default value. |
| `--reload` | <yes> |  | Reload the service after saving settings. |

## Examples

```
// set the banned_rules
warden --task=contentfilter:scanner --banned_rules=''\''ALLOW_MS_OFFICE'\'' => new_RE([qr'\''.\.(doc|docx|xls|xlsx|ppt|pptx)$'\''i => 0]), '\''DEFAULT'\'' => $banned_filename_re' --reload=yes

// reset the banned_rules to default
warden --task=contentfilter:scanner --default_option=banned_rules --reload=yes

// reset all settings to defaults
warden --task=contentfilter:scanner --default=yes --reload=yes

// disable the backup clamscan scanner to free memory on a busy server
warden --task=contentfilter:scanner --av_scanners_backup=none --reload=yes
```

## Related Pages

- [Filter Settings](https://docs.danami.com/warden/settings/contentfilter/filter-settings "Filter Settings")
- [Policy Banks](https://docs.danami.com/warden/settings/contentfilter/policy-banks "Policy Banks")
- [Scanner Settings](https://docs.danami.com/warden/settings/contentfilter/scanner-settings "Scanner Settings")
- [Milter Settings](https://docs.danami.com/warden/settings/contentfilter/milter-settings "Milter Settings")
- [Policy Settings](https://docs.danami.com/warden/settings/contentfilter/policy-settings "Policy Settings")

 [ ](https://docs.danami.com/warden/command-line-interface/contentfilter/contentfilter-policybanks) [](https://docs.danami.com/warden/settings/contentfilter/filter-settings)

---

## Navigation

- Previous: [contentfilter:policybanks](https://docs.danami.com/warden/command-line-interface/contentfilter/contentfilter-policybanks.md)
